# mdshare &mdash; CHANGELOG

## 0.1.0
-   provides `mdshare.load()`

## 0.2.0
-   switching to LGPL
-   adding tests and CI

### 0.2.1
-   removing numpy dependency
-   code cleanup

## 0.3.0
-   provides `mdshare.catalogue()` and `mdshare.search()`
-   deprecates `mdshare.load()`
-   provides `mdshare.fetch()` as successor to `mdshare.load()`

### 0.3.1
-   updates to documention and package

### 0.3.2
-   replaces FTP usage

## 0.4.0
-   added progressbars
-   major refactoring to have an offline catalogue available
-   allow to download/extract .tar.gz containers

### upcoming
-   removed obsolete/unsused imports/variables/...
-   replaced assert statements
